@@ -218,14 +218,24 @@ def build_parser():
         Print a list of all currently installed plugins.
         """,
     )
+    general.add_argument(
+        "--plugin-dir",
+        dest="plugin_dirs",
+        metavar="DIRECTORY",
+        action="append",
+        help="""
+        Load plugins from this directory.
+
+        Can be set multiple times to load plugins from multiple directories.
+        """,
+    )
     general.add_argument(
         "--plugin-dirs",
         metavar="DIRECTORY",
         type=comma_list,
+        action="extend",
         help="""
-        Attempts to load plugins from these directories.
-
-        Multiple directories can be used by separating them with a comma.
+        Load plugins from a list of comma-separated directories. (deprecated)
         """,
     )
     general.add_argument(
@@ -280,6 +290,33 @@ def build_parser():
         Default is "info".
         """,
     )
+    general.add_argument(
+        "--logformat",
+        metavar="FORMAT",
+        help="""
+        Set a custom logging format.
+
+        See the Python standard library's `logging.Formatter` docs for more information about the logging format
+        and the available `LogRecord` attributes. Streamlink's formatter uses the curly brace style.
+
+        The default format depends on the chosen log level (may include the `asctime` attribute).
+
+        Default is "[{name}][{levelname}] {message}".
+        """,
+    )
+    general.add_argument(
+        "--logdateformat",
+        metavar="DATEFORMAT",
+        help="""
+        Set a custom logging date format.
+
+        This formats the `LogRecord`'s `asctime` attribute via `strftime()`.
+
+        The default date format depends on the chosen log level (may include fractions).
+
+        Default is "%%H:%%M:%%S".
+        """,
+    )
     general.add_argument(
         "--logfile",
         metavar="FILE",
@@ -1118,6 +1155,18 @@ def build_parser():
         Path to write the output from the ffmpeg console.
         """,
     )
+    transport_ffmpeg.add_argument(
+        "--ffmpeg-loglevel",
+        type=str,
+        metavar="LOGLEVEL",
+        help="""
+        Change FFmpeg's `-loglevel` value to `LOGLEVEL`.
+
+        Unless --ffmpeg-verbose or --ffmpeg-verbose-path is set, changing the log level won't have any effect.
+
+        Default is "info".
+        """,
+    )
     transport_ffmpeg.add_argument(
         "--ffmpeg-fout",
         type=str,
@@ -1349,7 +1398,9 @@ def build_parser():
         Whether to launch the web browser in headless mode or not.
         When enabled, it stays completely hidden and doesn't require a desktop environment to run.
 
-        Default is true.
+        Please be aware that headless mode might be blocked by websites which implement bot detections.
+
+        Default is false.
         """,
     )
 
@@ -1410,6 +1461,7 @@ _ARGUMENT_TO_SESSIONOPTION: List[Tuple[str, str, Optional[Callable[[Any], Any]]]
     ("ffmpeg_no_validation", "ffmpeg-no-validation", None),
     ("ffmpeg_verbose", "ffmpeg-verbose", None),
     ("ffmpeg_verbose_path", "ffmpeg-verbose-path", None),
+    ("ffmpeg_loglevel", "ffmpeg-loglevel", None),
     ("ffmpeg_fout", "ffmpeg-fout", None),
     ("ffmpeg_video_transcode", "ffmpeg-video-transcode", None),
     ("ffmpeg_audio_transcode", "ffmpeg-audio-transcode", None),
